<?php
#
# (c) 2011 Charel Buchler <charel.buechler@caritas.lu>
# Robert Fisch <robert.fisch@caritas.lu>
# angepasst, aktualisiert, eingedeutscht: Andreas Dumont <ad@com-professional.de>
#
# This is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# MonitorDuino is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#

include('config.php');

// Reporting aktivieren
error_reporting(0);

// Verzeichnis setzen
chdir($basedir);

/**
* DATEN EINLESEN
**/

// curl-Handle erzeugen
$ch = curl_init($arduino);

// ausfhren
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
$json_data = curl_exec($ch);

// Fehler?
if(curl_errno($ch)){die('Could not retrieve data');}

// Handle schlieen
curl_close($ch);

// Daten vom Arduino behandeln
$jsonObj = json_decode($json_data); // JSON-String decodieren

// JSON-Daten verarbeiten
$temprature = $jsonObj->{'tmp'}; // Temperatur
$pressure = $jsonObj->{'pressure'}; // Luftdruck
$light = $jsonObj->{'light'}; // Helligkeit
$tightness = $jsonObj->{'tightness'}; // Luftfeuchtigkeit
$date = date("m.d.y H:i:s"); // Datum und Zeit

/**
* RRD-DATENBANK AKTUALISIEREN
**/

// Syntax von $output = <temperature>:<pressure>:<humidity>:<light>
$output = $temprature.":".$pressure.":".$tightness.":".$light;
`/usr/bin/rrdtool update arduinoDaily.rrd -t temperature:pressure:humidity:light N:$output`;
`/usr/bin/rrdtool update arduinoWeekly.rrd -t temperature:pressure:humidity:light N:$output`;
`/usr/bin/rrdtool update arduinoMonthly.rrd -t temperature:pressure:humidity:light N:$output`;
`/usr/bin/rrdtool update arduinoYearly.rrd -t temperature:pressure:humidity:light N:$output`;

/**
* PLOT GRAPHS
**/

plotGraph('arduinoDaily.rrd','MonitorDuino Tages-Statistik','d');
plotGraph('arduinoWeekly.rrd','MonitorDuino Wochen-Statistik','w');
plotGraph('arduinoMonthly.rrd','MonitorDuino Monats-Statistik','m');
plotGraph('arduinoYearly.rrd','MonitorDuino Jahres-Statistik','y');

/*****
* FUNKTIONEN
*/

/**
* function to plot a graph
*
* @param $archive ist die RRD-Datei
* @param $title ist der Titel der ber der Grafik steht
* @param $intervall Intervall = {d|w|m|y}
* @param $destination ist das Ziel-Verzeichnis (default = the current directory)
*/

function plotGraph($archive,$title,$intervall,$destination='.')
{
    // ja, der folgende Code gehrt in eine Zeile!
    `/usr/bin/rrdtool graph $destination/graph_$intervall.png --title="$title" -E DEF:temperature=$archive:temperature:AVERAGE DEF:pressure=$archive:pressure:AVERAGE CDEF:pressureMOD=pressure,-1000,+ DEF:humidity=$archive:humidity:AVERAGE DEF:light=$archive:light:AVERAGE VDEF:temperatureMAX=temperature,MAXIMUM VDEF:temperatureMIN=temperature,MINIMUM VDEF:temperatureAVG=temperature,AVERAGE VDEF:temperatureCUR=temperature,LAST VDEF:pressureMAX=pressure,MAXIMUM VDEF:pressureMIN=pressure,MINIMUM VDEF:pressureAVG=pressure,AVERAGE VDEF:pressureCUR=pressure,LAST VDEF:humidityMAX=humidity,MAXIMUM VDEF:humidityMIN=humidity,MINIMUM VDEF:humidityAVG=humidity,AVERAGE VDEF:humidityCUR=humidity,LAST VDEF:lightMAX=light,MAXIMUM VDEF:lightMIN=light,MINIMUM VDEF:lightAVG=light,AVERAGE VDEF:lightCUR=light,LAST COMMENT:"\t\t\t\t   Aktuell\t  Minimum\t Maximum\t Mittelwert\l" LINE2:temperature#FF0000:"Temperatur (C)\t\t" GPRINT:temperatureCUR:"%7.2lf\t" GPRINT:temperatureMIN:"%7.2lf\t" GPRINT:temperatureMAX:"%7.2lf\t" GPRINT:temperatureAVG:"%7.2lf\l" LINE2:pressureMOD#00FF00:"Luftdruck (hPa)\t\t" GPRINT:pressureCUR:"%7.2lf\t" GPRINT:pressureMIN:"%7.2lf\t" GPRINT:pressureMAX:"%7.2lf\t" GPRINT:pressureAVG:"%7.2lf\l" LINE2:humidity#0000FF:"Luftfeuchtigkeit (%)\t" GPRINT:humidityCUR:"%7.2lf\t" GPRINT:humidityMIN:"%7.2lf\t" GPRINT:humidityMAX:"%7.2lf\t" GPRINT:humidityAVG:"%7.2lf\l" LINE2:light#fe9d29:"Helligkeit (%)\t\t" GPRINT:lightCUR:"%7.2lf\t" GPRINT:lightMIN:"%7.2lf\t" GPRINT:lightMAX:"%7.2lf\t" GPRINT:lightAVG:"%7.2lf\l" -w 800 -h 200 -s -1$intervall -l 0`;
}

?>