// MonitorDuino Andreas Dumont ad@com-professional.de

// Bibliotheken einbinden
#include <Adafruit_BMP085_U.h>
#include <Adafruit_Sensor.h>
#include <DHT.h>
#include <DHT_U.h>
#include <SPI.h>
#include <Ethernet.h>
#include <Wire.h>

// Konstanten definieren
#define DHTPIN 8
#define DHTTYPE DHT22

//Variablen definieren
// MAC-Adresse des Ethernet-Shields
// steht auf der Unterseite
byte mac[] = {
  0x90, 0xA2, 0xDA, 0x00, 0x20, 0xD6
};
// IP-Adresse des Arduino
IPAddress ip(172, 20, 11, 202);
EthernetServer server(80);
DHT_Unified dht(DHTPIN, DHTTYPE);
Adafruit_BMP085_Unified bmp = Adafruit_BMP085_Unified(10085);

// Setup
void setup()
{
  // Sensoren initialisieren
  Ethernet.begin(mac, ip);
  server.begin();
  dht.begin();
  bmp.begin();
}

// Funktion zum Auslesen des Licht-Sensors
float getLight() {
  return (analogRead(A3) / 1024.0) * 100;
}

// Loop
void loop()
{
  // Wartezeit zwischen den Messungen
  delay(2000);  
  sensors_event_t event;
  float temperature;
  // auf Clients warten
  EthernetClient client = server.available();
  if (client) {
    // HTTP-Requests enden mit einer leeren Zeile
    boolean currentLineIsBlank = true;
    while (client.connected()) {
      if (client.available()) {
        char c = client.read();
		// Zeilenumbruch gefolgt von leerer Zeile
		// bedeutet, der HTTP-Request ist beendet
        if (c == '\n' && currentLineIsBlank) {
          // sende HTTP-Response Header
          client.println("HTTP/1.1 200 OK");
          client.println("Content-Type: text/plain");
          client.println();
          // Sensordaten auslesen und ausgeben
          client.print("{\"tmp\":\"");
          // Temperatur wahlweise von BMP180 oder DHT22
          bmp.getTemperature(&temperature);
     //   dht.temperature().getEvent(&event);
          client.print(temperature);
          client.print("\"");
          client.print(",");
          client.print("\"pressure\"");
          client.print(":");
          client.print("\"");
          bmp.getEvent(&event);
          client.print(event.pressure);
          client.print("\",");
          client.print("\"light\":");
          client.print("\"");
          client.print(getLight());
          client.print("\"");
          client.print(",");
          client.print("\"tightness\":");
          client.print("\"");
          dht.humidity().getEvent(&event);
          client.print(event.relative_humidity);
          client.print("\"");
          client.print("}");
          break;
        }
        if (c == '\n') {
          // leere Zeile
          currentLineIsBlank = true;
        }
        else if (c != '\r') {
          // keine leere Zeile
          currentLineIsBlank = false;
        }
      }
    } // warte 50 Millisekunden
    delay(50);
    // beende die Verbindung
    client.stop();
  }
}
